@@ -9,10 +9,6 @@ use Storable qw(nstore retrieve);
 use Scalar::Util qw(blessed);
 
 use KiokuDB;
-use KiokuDB::Backend::Hash;
-use KiokuDB::Backend::JSPON;
-use KiokuDB::Backend::BDB;
-#use KiokuDB::Backend::CouchDB;
 
 # no long running tests
 my $large = 0;
@@ -30,33 +26,22 @@ sub bench {
 
     my $storable = $dir->file("foo.storable")->stringify;
 
-    my $mxsd_hash = KiokuDB->new(
-        backend => KiokuDB::Backend::Hash->new,
-    );
+    my $mxsd_hash = KiokuDB->connect("hash");
 
-    my $mxsd_jspon = KiokuDB->new(
-        backend => KiokuDB::Backend::JSPON->new(
-            dir  => $dir->subdir("mxsd_jspon"),
-            lock => 0,
-        ),
-    );
+    my $mxsd_files = KiokuDB->connect("files:dir=" . $dir->subdir("mxsd_files"), create => 1, lock => 0 );
 
-    my $mxsd_bdb_txn = KiokuDB->new(
-        backend => KiokuDB::Backend::BDB->new(
-            manager => { home => $dir->subdir("mxsd_bdb_txn"), create => 1 }
-        ),
-    );
+    my $mxsd_bdb_txn = KiokuDB->connect("bdb:dir=" . $dir->subdir("mxsd_bdb_txn"), create => 1 );
 
-    my $mxsd_sqlite = KiokuDB->connect("dbi:SQLite:dbname=" . $dir->file("sqlite.db") );
+    my $mxsd_sqlite = KiokuDB->connect("dbi:SQLite:dbname=" . $dir->file("sqlite.db"), serializer => "storable" );
 
     $mxsd_sqlite->backend->dbh->do("PRAGMA default_synchronous = OFF");
 
     $mxsd_sqlite->backend->deploy;
 
-    my $mxsd_mysql = eval { KiokuDB->connect("dbi:mysql:test") }; warn $@ if $@;
+    my $mxsd_mysql = eval { KiokuDB->connect("dbi:mysql:test", serializer => "storable") }; warn $@ if $@;
     $mxsd_mysql && $mxsd_mysql->backend->deploy({ add_drop_table => 1, producer_args => { mysql_version => 5 } });
 
-    my $mxsd_pg = eval { KiokuDB->connect("dbi:Pg:dbname=test") }; warn $@ if $@;
+    my $mxsd_pg = eval { KiokuDB->connect("dbi:Pg:dbname=test", user => "postgres", password => "290685kj", serializer => "storable") }; warn $@ if $@;
     $mxsd_pg && $mxsd_pg->backend->deploy({ add_drop_table => 1 });
 
     $dir->subdir("mxsd_bdb_dumb")->mkpath;
@@ -97,7 +82,7 @@ sub bench {
         cmpthese(-3, {
             #null         => sub { my @objs = construct(); },
             mxsd_hash    => sub { my @objs = construct(); my $s = $mxsd_hash->new_scope; $mxsd_hash->store(grep { blessed($_) } @objs) },
-            mxsd_jspon   => sub { my @objs = construct(); my $s = $mxsd_jspon->new_scope; $mxsd_jspon->store(grep { blessed($_) } @objs) },
+            mxsd_files   => sub { my @objs = construct(); my $s = $mxsd_files->new_scope; $mxsd_files->store(grep { blessed($_) } @objs) },
             mxsd_bdb     => sub { my @objs = construct(); my $s = $mxsd_bdb_dumb->new_scope; $mxsd_bdb_dumb->store(grep { blessed($_) } @objs) },
             mxsd_bdb_txn => sub { my @objs = construct(); my $s = $mxsd_bdb_txn->new_scope; $mxsd_bdb_txn->store(grep { blessed($_) } @objs) },
             mxsd_sqlite  => sub { my @objs = construct(); my $s = $mxsd_sqlite->new_scope; $mxsd_sqlite->store(grep { blessed($_) } @objs) },
@@ -113,7 +98,7 @@ sub bench {
 
     nstore([ construct() ], $storable);
     my @hash_ids  = do { my @objs = construct(); my $s = $mxsd_hash->new_scope; $mxsd_hash->store(grep { blessed($_) } @objs) };
-    my @jspon_ids = do { my @objs = construct(); my $s = $mxsd_jspon->new_scope; $mxsd_jspon->store(grep { blessed($_) } @objs) };
+    my @files_ids = do { my @objs = construct(); my $s = $mxsd_files->new_scope; $mxsd_files->store(grep { blessed($_) } @objs) };
     my @bdb_d_ids = do { my @objs = construct(); my $s = $mxsd_bdb_dumb->new_scope; $mxsd_bdb_dumb->store(grep { blessed($_) } @objs) };
     my @bdb_t_ids = do { my @objs = construct(); my $s = $mxsd_bdb_txn->new_scope; $mxsd_bdb_txn->backend->txn_do(sub { $mxsd_bdb_txn->store(grep { blessed($_) } @objs) }); };
     my @sqlite_t_ids = do { my @objs = construct(); my $s = $mxsd_sqlite->new_scope; $mxsd_sqlite->backend->txn_do(sub { $mxsd_sqlite->store(grep { blessed($_) } @objs) }); };
@@ -124,7 +109,7 @@ sub bench {
     cmpthese(-3, {
         storable     => sub { my $objs = retrieve($storable) },
         mxsd_hash    => sub { my $s = $mxsd_hash->new_scope; my @objs = $mxsd_hash->lookup(@hash_ids) },
-        mxsd_jspon   => sub { my $s = $mxsd_jspon->new_scope; my @objs = $mxsd_jspon->lookup(@jspon_ids) },
+        mxsd_files   => sub { my $s = $mxsd_files->new_scope; my @objs = $mxsd_files->lookup(@files_ids) },
         mxsd_bdb     => sub { my $s = $mxsd_bdb_dumb->new_scope; my @objs = $mxsd_bdb_dumb->lookup(@bdb_d_ids) },
         mxsd_bdb_txn => sub { my $s = $mxsd_bdb_txn->new_scope; my @objs = $mxsd_bdb_txn->lookup(@bdb_t_ids) },
         mxsd_sqlite  => sub { my $s = $mxsd_sqlite->new_scope; my @objs = $mxsd_sqlite->lookup(@sqlite_t_ids) },
